Learn R Programming

CNLTtsa (version 0.1-2)

CNLTtsa-package: CNLTtsa

Description

CNLTtsa

Arguments

Details

The DESCRIPTION file: CNLTtsa CNLTtsa

The main routines of the package are cnlt.univ and cnlt.biv which perform the nondecimated complex-valued lifting transform for univariate and bivariate time series, respectively; cnlt.spec computes spectral quantities of interest, for example the coherence and phase between two components of a bivariate series.

References

Hamilton, J., Nunes, M. A, Knight, M. I. and Fryzlewicz, P. (2018) Complex-valued wavelet lifting and applications. Technometrics, 60 (1), 48-60, DOI 10.1080/00401706.2017.1281846. For related literature on the lifting methodology adopted in the technique, see Knight, M. I. and Nason, G. P. (2009) A 'nondecimated' wavelet transform. Stat. Comput. 19 (1), 1--16. Knight, M. I., Nunes, M. A. and Nason, G. P. (2012) Spectral Estimation for Locally Stationary Time Series with Missing Observations. Stat. Comput. 22 (4), 877--895.

See Also

cnlt.reg