The function takes a nondecimated complex lifting decomposition of a univariate or bivariate series, and uses smoothing before computing spectral quantities such as the complex periodograms, coherence and phase
cnlt.spec(x, ...)
# S3 method for SG
cnlt.spec(x, M = 50, fact = 1, ...)
# S3 method for DG
cnlt.spec(x, M = 50, fact = 1, ...)The smoothing parameter (binwidth) or vector of smoothing parameters (one for each scale) for the time-domain kernel smoothing method, see smooth.over.time.
If length(M)==1, a factor indicating how the smoothing parameter (binwidth) in the time-domain kernel smoothing method should increase from
one scale to the next, see smooth.over.time.
Any other parameters to be passed to the scale smoothing function, see the documentation for smooth.over.scale for univariate cnlt objects, or pre.per for bivariate cnlt objects.
An object of class cnlt.spec (subclasses: DG, SG, univ, biv).
For subclass univ, a list with components:
A spectral object (matrix) of dimension length(mscale) x length(mtime), corresponding to the spectrum of the univariate series.
A vector of scales corresponding to the rows of the spectrum S1 (after smoothing the periodogram), see smooth.over.scale.
The vector cnltobj$x, the vector of times corresponding to the columns of the spectrum S1.
For subclass biv, a list with components:
A matrix of dimension length(mscale) x length(mtime), corresponding to the coherence between the two components of the bivariate series.
A matrix of dimension length(mscale) x length(mtime), corresponding to the phase between the two components of the bivariate series.
A matrix of dimension length(mscale) x length(mtime), corresponding to the co-periodogram of the bivariate series.
A matrix of dimension length(mscale) x length(mtime), corresponding to the quadrature periodogram of the bivariate series.
A matrix of dimension length(mscale) x length(mtime), corresponding to the spectrum of the first component of the bivariate series.
A matrix of dimension length(mscale) x length(mtime), corresponding to the spectrum of the second component of the bivariate series.
A vector of scales corresponding to the rows of the spectrum S1 (after smoothing the periodogram), see smooth.over.scale.
A vector of times corresponding to the columns of the spectrum S1. If the class of cnlt.obj is SG, this is cnlt.obj$x1, else this is a vector formed by binning detail coefficients within equal intervals of time, see pre.per for more details.
For univariate series, the nondecimated complex lifting object can be used to form a spectral object by smoothing the squared details over scale (with smooth.over.scale), and then smoothing over time (using smooth.over.time). Smoothing over scale is done via smooth.spline; smoothing over time is done with a kernel smoother (e.g. a "box" kernel for a moving average).
See Hamilton et al. (2018) for more details.
Hamilton, J., Nunes, M. A., Knight, M. I. and Fryzlewicz, P. (2018) Complex-valued wavelet lifting and applications. Technometrics, 60 (1), 48-60, DOI 10.1080/00401706.2017.1281846.
# NOT RUN {
# read some data in (a bivariate series)
# }
# NOT RUN {
data(Baidu)
data(Google)
BaiGoo<-cnlt.biv(Baidu$Seconds[1:100], Google$Seconds[1:100], Baidu$Return[1:100],
Google$Return[1:100], P = 500)
specobj<-cnlt.spec(BaiGoo,M=10,fact=1.05, Tstar=20)
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab